==> teamapps-client-0.9.66.zip: tsd/modules/formfield/UiCheckBox.d.ts <==
import { UiCheckBoxCommandHandler, UiCheckBoxConfig, UiCheckBoxEventSource } from "../../generated/UiCheckBoxConfig";
import { UiFieldEditingMode } from "../../generated/UiFieldEditingMode";
import { UiField } from "./UiField";
import { TeamAppsUiContext } from "../TeamAppsUiContext";
import { UiColorConfig } from "../../generated/UiColorConfig";
import { UiFieldMessageConfig } from "../../generated/UiFieldMessageConfig";
export declare class UiCheckBox extends UiField<UiCheckBoxConfig, boolean> implements UiCheckBoxEventSource, UiCheckBoxCommandHandler {
    private $main;
    private $check;
    private $label;
    private $style;
    private backgroundColor;
    private checkColor;
    private borderColor;
    protected initialize(config: UiCheckBoxConfig, context: TeamAppsUiContext): void;
    isValidData(v: boolean): boolean;
    private toggleCommittedValue;
    getMainInnerDomElement(): HTMLElement;
    setCaption(caption: string): void;
    setBackgroundColor(backgroundColor: UiColorConfig): void;
    setCheckColor(checkColor: UiColorConfig): void;
    setBorderColor(borderColor: UiColorConfig): void;
    setFieldMessages(fieldMessageConfigs: UiFieldMessageConfig[]): void;
    private updateStyles;
    getFocusableElement(): HTMLElement;
    protected displayCommittedValue(): void;
    focus(): void;
    getTransientValue(): boolean;
    protected onEditingModeChanged(editingMode: UiFieldEditingMode): void;
    getReadOnlyHtml(value: boolean, availableWidth: number): string;
    getDefaultValue(): boolean;
    valuesChanged(v1: boolean, v2: boolean): boolean;
}

==> teamapps-client-0.9.119.zip: tsd/modules/formfield/UiCheckBox.d.ts <==
import { UiCheckBoxCommandHandler, UiCheckBoxConfig, UiCheckBoxEventSource } from "../../generated/UiCheckBoxConfig";
import { UiFieldEditingMode } from "../../generated/UiFieldEditingMode";
import { UiField } from "./UiField";
import { TeamAppsUiContext } from "../TeamAppsUiContext";
import { UiFieldMessageConfig } from "../../generated/UiFieldMessageConfig";
export declare class UiCheckBox extends UiField<UiCheckBoxConfig, boolean> implements UiCheckBoxEventSource, UiCheckBoxCommandHandler {
    private $main;
    private $check;
    private $label;
    private $style;
    private backgroundColor;
    private checkColor;
    private borderColor;
    protected initialize(config: UiCheckBoxConfig, context: TeamAppsUiContext): void;
    isValidData(v: boolean): boolean;
    private toggleCommittedValue;
    getMainInnerDomElement(): HTMLElement;
    setCaption(caption: string): void;
    setBackgroundColor(backgroundColor: string): void;
    setCheckColor(checkColor: string): void;
    setBorderColor(borderColor: string): void;
    setFieldMessages(fieldMessageConfigs: UiFieldMessageConfig[]): void;
    private updateStyles;
    getFocusableElement(): HTMLElement;
    protected displayCommittedValue(): void;
    focus(): void;
    getTransientValue(): boolean;
    protected onEditingModeChanged(editingMode: UiFieldEditingMode): void;
    getReadOnlyHtml(value: boolean, availableWidth: number): string;
    getDefaultValue(): boolean;
    valuesChanged(v1: boolean, v2: boolean): boolean;
}
